Skip to contents

Function to remove all unneeded species data and to format column names as needed for the NWFS HKL data.

Usage

clean_nwfsc_hkl(dir = dir, data, species)

Arguments

dir

Directory location to save the cleaned data frame

data

Data frame of NWFSC HKL data

species

A list of species names created by the get_species_list function

Author

Chantel Wetzel