clean_nwfsc_hkl.Rd
Function to remove all unneeded species data and to format column names as needed for the NWFS HKL data.
clean_nwfsc_hkl(dir = dir, data, species)
Directory location to save the cleaned data frame
Data frame of NWFSC HKL data
A list of species names created by the get_species_list function
Chantel Wetzel